@@ -21,8 +21,12 @@
 ## create generics
 
 # is now a generic in R 2.11.0
-#setGeneric("%in%",
-#    function(x, table) standardGeneric("%in%"))
+setGeneric("%in%")
+#setGeneric("%in%", function(x, table) match(x, table, nomatch = 0) > 0)
+
+## this complains because we add ... 
+setGeneric("abbreviate", function(names.arg, ...) 
+  base::abbreviate(names.arg, ...))
 
 setGeneric("%pin%",
     function(x, table) standardGeneric("%pin%"))
@@ -33,8 +37,9 @@ setGeneric("%ain%",
 setGeneric("LIST",
     function(from, ...) standardGeneric("LIST"))
 
+## this complains because we add ... 
 setGeneric("write",
-    function(x, file = "", ...) standardGeneric("write"))
+    function(x, file = "", ...) base::write(x, file, ...))
 
 setGeneric("addComplement",
     function(x, labels, complementLabels=NULL) standardGeneric("addComplement"))
@@ -59,6 +64,13 @@ setGeneric("encode",
 setGeneric("generatingItemsets",
     function(x) standardGeneric("generatingItemsets"))
 
+# somehow redefining the generic funciton this is necessary
+setGeneric("head",
+    function(x, ...) standardGeneric("head"))
+
+setGeneric("info",
+    function(x) standardGeneric("info"))
+
 setGeneric("info",
     function(x) standardGeneric("info"))
 
